Welcome to Pyslet
=================

Pyslet is a Python package for Standards in Learning Education and
Training (LET). It implements a number of LET-specific standards,
including IMS QTI, Content Packaging and Basic LTI.  It also includes
support for some general standards, including the data access standard
OData (see http://www.odata.org).

Pyslet was originally written to be the engine behind the QTI migration
tool but it can be used independently as a support module for your own
Python applications.

Current Status & Road Map
~~~~~~~~~~~~~~~~~~~~~~~~~

Pyslet is going through a transition process at the moment as the QTI
migration tool that drives its development is gradually moving towards
being distributed as an LTI tool rather than a desktop application.

The OData support is fairly robust, it is used to run the Cambridge Weather
OData service which can be found at http://odata.pyslet.org/weather

What's next?

* Proper Media stream support in the OData SQL storage model
* MySQL shim for the OData SQL storage model
* Improved support for LTI to take it beyond 'basic'

I write about Pyslet on my blog, which is a good place to find out
what's new: http://swl10.blogspot.co.uk/


Feedback
~~~~~~~~

The code is maintained on Google Code:
https://code.google.com/p/qtimigration/

Issues can be raised on the project site - all feedback welcome.

You can find out more about me and contact me directly through my Google
profile page.

Pyslet is written and maintained by the main author on a spare time
basis and is not connected to my current employer.

As I don't have much spare time, the code tends to be fairly stable. 
Some of the code was written almost 20 years ago and it owes a lot to
the University of Cambridge that employed me for many years in a variety
of different roles.


License
~~~~~~~

Pyslet is distributed under the 'New' BSD license:
http://opensource.org/licenses/BSD-3-Clause, this decision was inherited
from the early days of the code.  Although Copyright to much of the
source is owned by the author personally earlier parts are owned by the
University of Cambridge and are marked as such.

 
 


